@@ -13,6 +13,7 @@ from pycoMeth.CpG_Aggregate import CpG_Aggregate
 from pycoMeth.Interval_Aggregate import Interval_Aggregate
 from pycoMeth.Meth_Comp import Meth_Comp
 from pycoMeth.CGI_Finder import CGI_Finder
+from pycoMeth.Comp_Report import Comp_Report
 
 #~~~~~~~~~~~~~~TOP LEVEL ENTRY POINT~~~~~~~~~~~~~~#
 def main(args=None):
@@ -70,6 +71,20 @@ def main(args=None):
     arg_from_docstr(sp_met_ms, f, "pvalue_adj_method")
     arg_from_docstr(sp_met_ms, f, "pvalue_threshold")
 
+    # Comp_Report subparser
+    f = Comp_Report
+    sp_cr = subparsers.add_parser("Comp_Report", description=doc_func(f))
+    sp_cr.set_defaults(func=f)
+    sp_cr_io = sp_cr.add_argument_group("Input/Output options")
+    arg_from_docstr(sp_cr_io, f, "methcomp_fn", "i")
+    arg_from_docstr(sp_cr_io, f, "gff3_fn", "g")
+    arg_from_docstr(sp_cr_io, f, "outdir", "o")
+    sp_cr_ms = sp_cr.add_argument_group("Misc options")
+    arg_from_docstr(sp_cr_ms, f, "n_top", "n")
+    arg_from_docstr(sp_cr_ms, f, "max_tss_distance", "d")
+    arg_from_docstr(sp_cr_ms, f, "pvalue_threshold")
+    arg_from_docstr(sp_cr_ms, f, "min_diff_llr")
+
     # CGI_Finder subparser
     f = CGI_Finder
     sp_cgi = subparsers.add_parser("CGI_Finder", description=doc_func(f))
@@ -85,7 +100,7 @@ def main(args=None):
     arg_from_docstr(sp_cgi_ms, f, "min_obs_CG_ratio", "r")
 
     # Add common group parsers
-    for sp in [sp_cpg, sp_int, sp_met, sp_cgi]:
+    for sp in [sp_cpg, sp_int, sp_met, sp_cr, sp_cgi]:
         sp_vb = sp.add_argument_group("Verbosity options")
         sp_vb.add_argument("-v", "--verbose", action="store_true", default=False, help="Increase verbosity")
         sp_vb.add_argument("-q", "--quiet", action="store_true", default=False, help="Reduce verbosity")
